==> estateplat-common-1.2.3-20180628.030850-131-sources.jar: cn/gtmap/estateplat/model/server/core/GdFwQl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/*
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0,2016/4/19.
 * @description 房屋权利查询属性结构描述
 */
@Table(name = "gd_fw_ql")
public class GdFwQl {
    @Id
    private String qlid;
    private String proid;
    private String fczh;
    private String qlr;
    private String fwzl;
    private String djlx;
    private String fjh;
    private String zslx;
    private String qlrzjh;//权利人证件号
    //增加冗余字段
    private String ywrzjh;//义务人证件号
    private String bdcdybh;//不动产单元编号
    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }


    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getFczh() {
        return fczh;
    }

    public void setFczh(String fczh) {
        this.fczh = fczh;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getZslx() {
        return zslx;
    }

    public void setZslx(String zslx) {
        this.zslx = zslx;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }
}

==> estateplat-common-1.2.4-20181228.083806-80-sources.jar: cn/gtmap/estateplat/model/server/core/GdFwQl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/*
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0,2016/4/19.
 * @description 房屋权利查询属性结构描述
 */
@Table(name = "gd_fw_ql")
public class GdFwQl {
    @Id
    private String qlid;
    private String proid;
    private String fczh;
    private String qlr;
    private String fwzl;
    private String djlx;
    private String fjh;
    private String zslx;
    private String qlrzjh;//权利人证件号
    //增加冗余字段
    private String ywrzjh;//义务人证件号
    private String bdcdybh;//不动产单元编号
    private String iszx;//是否注销
    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }


    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getFczh() {
        return fczh;
    }

    public void setFczh(String fczh) {
        this.fczh = fczh;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getZslx() {
        return zslx;
    }

    public void setZslx(String zslx) {
        this.zslx = zslx;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getIszx() {
        return iszx;
    }

    public void setIszx(String iszx) {
        this.iszx = iszx;
    }
}
